@@ -209,7 +209,7 @@ class Activation(ABC):
         else:
             val_xor = np.logical_xor(self.raw, other.raw)
             val_and = self.raw * other.raw
-            val = np.logical_xor(val_xor ^ val_and).astype("int32")
+            val = np.logical_xor(val_xor, val_and).astype("int32")
         return Activation(val, length=self.length)
 
     def __sub__(self, other: "Activation") -> "Activation":
@@ -337,7 +337,7 @@ class Activation(ABC):
         >>> Activation._array_to_int(np.array([0, 1, 1, 0]))
         6  # the binary number '0110' is 6 in base 10
         """
-        return int("".join(str(i) for i in value), 2)
+        return int("".join(str(i) for i in value.astype('int')), 2)
 
     @property
     def raw(self) -> np.ndarray:
